Module command

Module command 

Structs

CommandEntry
Metadata for a single entry in the command palette.

Enums

TuiCommand
Commands dispatched from the TUI command palette to the agent loop.

Functions

command_registry
Returns the static registry of core TUI commands.
daemon_command_registry
Returns the static registry of daemon / remote-connection commands.
extra_command_registry
Returns the extended command registry (infrastructure, agent, plan, graph, experiment).
filter_commands
Filter and rank all registered commands by fuzzy match against query.