pub enum InputMode {
Normal,
Insert,
}Expand description
The current text-input mode of the TUI.
Inspired by modal editors: in Normal mode key bindings trigger actions;
in Insert mode printable characters are appended to the input buffer.
Examples
use zeph_tui::InputMode;
let mode = InputMode::Insert;
assert_eq!(mode, InputMode::Insert);Variants
Normal
Navigation and command keybindings are active; typing does not insert text.
Insert
Text is inserted into the input field on every printable key press.