Structs
- Command
Entry - Metadata for a single entry in the command palette.
Enums
- TuiCommand
- Commands dispatched from the TUI command palette to the agent loop.
Functions
- command_
registry - Returns the static registry of core TUI commands.
- daemon_
command_ registry - Returns the static registry of daemon / remote-connection commands.
- extra_
command_ registry - Returns the extended command registry (infrastructure, agent, plan, graph, experiment).
- filter_
commands - Filter and rank all registered commands by fuzzy match against
query. - zeph_
commands_ entries - Returns the
CommandEntryprojection of everyzeph_commands::COMMANDSentry that has no dedicated hand-authoredTuiCommand(seeZEPH_COMMANDS_DEDUP).