pub struct Theme {Show 27 fields
pub user_message: Style,
pub assistant_message: Style,
pub system_message: Style,
pub input_text: Style,
pub input_cursor: Style,
pub status_bar: Style,
pub header: Style,
pub panel_border: Style,
pub panel_title: Style,
pub highlight: Style,
pub error: Style,
pub thinking_message: Style,
pub code_inline: Style,
pub code_block: Style,
pub streaming_cursor: Style,
pub tool_command: Style,
pub assistant_accent: Style,
pub tool_accent: Style,
pub diff_added_bg: Color,
pub diff_removed_bg: Color,
pub diff_word_added_bg: Color,
pub diff_word_removed_bg: Color,
pub diff_gutter_add: Style,
pub diff_gutter_remove: Style,
pub diff_header: Style,
pub link: Style,
pub table_border: Style,
}Expand description
Visual theme for the TUI dashboard widgets.
Contains Style values for every distinct UI element — message roles,
input fields, borders, diff gutters, hyperlinks, and status elements.
The Default implementation provides a dark blue colour scheme.
Examples
use zeph_tui::theme::Theme;
let theme = Theme::default();
// User and assistant messages use distinct colours.
assert_ne!(theme.user_message, theme.assistant_message);Fields
user_message: Styleassistant_message: Stylesystem_message: Styleinput_text: Styleinput_cursor: Stylestatus_bar: Styleheader: Stylepanel_border: Stylepanel_title: Stylehighlight: Styleerror: Stylethinking_message: Stylecode_inline: Stylecode_block: Stylestreaming_cursor: Styletool_command: Styleassistant_accent: Styletool_accent: Stylediff_added_bg: Colordiff_removed_bg: Colordiff_word_added_bg: Colordiff_word_removed_bg: Colordiff_gutter_add: Stylediff_gutter_remove: Stylediff_header: Stylelink: Styletable_border: StyleTrait Implementations